CHANGELOG
=========

1.0.0 - 2025-01-12
------------------

Initial release as namespace plugin

Contributed by [Arul](https://github.com/arulrajnet) via [PR #1](https://github.com/pelican-plugins/statistics/pull/1/)


